Overview
========

lvlspy is a python package for working with quantum-level system data.

Installation
------------

Install from `PyPI <https://pypi.org/project/wnutils>`_ with pip by
typing in your favorite terminal::

    $ pip install lvlspy

Usage
-----

To get familiar with lvlspy, please see our tutorial Jupyter
`notebooks <https://github.com/jaadt7/lvlspy_tutorial>`_.

Authors
-------

- Jaad A. Tannous <jtannou@g.clemson.edu>
- Bradley S. Meyer <mbradle@g.clemson.edu>

Contribute
----------

- Issue Tracker: `<https://github.com/jaadt7/issues/>`_
- Source Code: `<https://github.com/jaadt7/lvlspy/>`_

License
-------

The project is licensed under the GNU Public License v3 (or later).

